==> botrun_ask_folder-4.8.181-py2.py3-none-any.whl: botrun_ask_folder/services/drive/fast_api_drive_client.py <==
import aiohttp
import os
from typing import List

from botrun_ask_folder.models.drive_folder import DriveFolder
from botrun_ask_folder.models.drive_file import DriveFile
from botrun_ask_folder.models.splitted_file import SplittedFile
from botrun_ask_folder.services.drive.drive_client import DriveClient

API_PREFIX = "api/botrun/botrun_ask_folder"


class FastAPIDriveClient(DriveClient):
    def __init__(self, api_url: str = os.getenv("FAST_API_URL")):
        self.api_url = api_url

    async def get_drive_folder(self, id: str) -> DriveFolder:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{id}"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFolder(**data)

    async def set_drive_folder(self, folder: DriveFolder) -> DriveFolder:
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_folder", json=folder.model_dump()
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFolder(**data["drive_folder"])

    async def delete_drive_folder(self, id: str) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.delete(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{id}"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data["message"] == "Status deleted successfully"

    async def get_drive_file(self, id: str) -> DriveFile:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_file/{id}"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFile(**data)

    async def set_drive_file(self, file: DriveFile) -> DriveFile:
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_file", json=file.model_dump()
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFile(**data["drive_file"])

    async def delete_drive_file(self, id: str) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.delete(
                f"{self.api_url}/{API_PREFIX}/drive_file/{id}"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data["message"] == "File deleted successfully"

    async def get_splitted_file(self, id: str) -> SplittedFile:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/splitted_file/{id}"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return SplittedFile(**data)

    async def set_splitted_file(self, file: SplittedFile) -> SplittedFile:
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/splitted_file", json=file.model_dump()
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return SplittedFile(**data["splitted_file"])

    async def delete_splitted_file(self, id: str) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.delete(
                f"{self.api_url}/{API_PREFIX}/splitted_file/{id}"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data["message"] == "Splitted file deleted successfully"

    async def update_drive_files(self, folder_id: str, new_files: List[DriveFile]):
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/update_files",
                json=[file.model_dump() for file in new_files],
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data

    async def get_split_files(self, folder_id: str):
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/split_files"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return {
                    name: SplittedFile(**file_data) for name, file_data in data.items()
                }

    async def get_drive_files(self, folder_id: str) -> List[DriveFile]:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/files"
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return [DriveFile(**file_data) for file_data in data]

==> botrun_ask_folder-4.8.231-py2.py3-none-any.whl: botrun_ask_folder/services/drive/fast_api_drive_client.py <==
import aiohttp
import os
from typing import List
from botrun_ask_folder.constants import FAST_API_TIMEOUT
from botrun_ask_folder.fast_api.util.http_request_retry_decorator import async_retry

from botrun_ask_folder.models.drive_folder import DriveFolder
from botrun_ask_folder.models.drive_file import DriveFile, DriveFileStatus
from botrun_ask_folder.models.splitted_file import SplittedFile
from botrun_ask_folder.services.drive.drive_client import DriveClient

API_PREFIX = "api/botrun/botrun_ask_folder"


class FastAPIDriveClient(DriveClient):
    def __init__(self, api_url: str = os.getenv("FAST_API_URL")):
        self.api_url = api_url

    @async_retry(attempts=3, delay=1)
    async def get_drive_folder(self, id: str) -> DriveFolder:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{id}",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFolder(**data)

    @async_retry(attempts=3, delay=1)
    async def set_drive_folder(self, folder: DriveFolder) -> DriveFolder:
        print(f"set_drive_folder {self.api_url}/{API_PREFIX}/drive_folder")
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_folder",
                json=folder.model_dump(),
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                print(f"set_drive_folder get response {data}")
                return DriveFolder(**data["drive_folder"])

    @async_retry(attempts=3, delay=1)
    async def delete_drive_folder(self, id: str) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.delete(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{id}",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data["message"] == "Status deleted successfully"

    @async_retry(attempts=3, delay=1)
    async def update_drive_file_status_in_folder(
        self, folder_id: str, file_id: str, new_status: DriveFileStatus
    ):
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/update_file_status",
                json={"file_id": file_id, "new_status": new_status.value},
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data

    @async_retry(attempts=3, delay=1)
    async def get_drive_file(self, id: str) -> DriveFile:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_file/{id}",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFile(**data)

    @async_retry(attempts=3, delay=1)
    async def set_drive_file(self, file: DriveFile) -> DriveFile:
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_file",
                json=file.model_dump(),
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return DriveFile(**data["drive_file"])

    @async_retry(attempts=3, delay=1)
    async def delete_drive_file(self, id: str) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.delete(
                f"{self.api_url}/{API_PREFIX}/drive_file/{id}",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data["message"] == "File deleted successfully"

    @async_retry(attempts=3, delay=1)
    async def get_splitted_file(self, id: str) -> SplittedFile:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/splitted_file/{id}",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return SplittedFile(**data)

    @async_retry(attempts=3, delay=1)
    async def set_splitted_file(self, file: SplittedFile) -> SplittedFile:
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/splitted_file",
                json=file.model_dump(),
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return SplittedFile(**data["splitted_file"])

    @async_retry(attempts=3, delay=1)
    async def delete_splitted_file(self, id: str) -> bool:
        async with aiohttp.ClientSession() as session:
            async with session.delete(
                f"{self.api_url}/{API_PREFIX}/splitted_file/{id}",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data["message"] == "Splitted file deleted successfully"

    @async_retry(attempts=3, delay=1)
    async def update_drive_files(self, folder_id: str, new_files: List[DriveFile]):
        async with aiohttp.ClientSession() as session:
            async with session.post(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/update_files",
                json=[file.model_dump() for file in new_files],
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return data

    @async_retry(attempts=3, delay=1)
    async def get_split_files(self, folder_id: str):
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/split_files",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return {
                    name: SplittedFile(**file_data) for name, file_data in data.items()
                }

    @async_retry(attempts=3, delay=1)
    async def get_drive_files(self, folder_id: str) -> List[DriveFile]:
        async with aiohttp.ClientSession() as session:
            async with session.get(
                f"{self.api_url}/{API_PREFIX}/drive_folder/{folder_id}/files",
                timeout=FAST_API_TIMEOUT,
            ) as response:
                response.raise_for_status()
                data = await response.json()
                return [DriveFile(**file_data) for file_data in data]
